@@ -11,7 +11,7 @@ from os.path import normpath, basename
 import time
 class VisionEnv(gym.Env):
     metadata = {'render.modes': ['human']}
-    def __init__(self, car_location=None, balls_location=None, humanoids_location=None, cam_height=None, visual_cam_settings=None):
+    def __init__(self, car_location=None, balls_location=None, humanoids_location=None, visual_cam_settings=None):
         p.connect(p.GUI)
         p.setAdditionalSearchPath(pybullet_data.getDataPath())
         p.setGravity(0,0,-10)
@@ -20,7 +20,6 @@ class VisionEnv(gym.Env):
         self.car_location = car_location
         self.balls_location = balls_location
         self.humanoids_location = humanoids_location
-        self.cam_height = cam_height
         self.visual_cam_settings = visual_cam_settings
     
         self.load_env()
@@ -30,15 +29,15 @@ class VisionEnv(gym.Env):
         if self.car_location is not None:
             self.car = p.loadURDF('urdf/car/car.urdf', self.car_location, p.getQuaternionFromEuler([0,0,3.14]))  
         if self.balls_location is not None:
-            self.ball = p.loadURDF('urdf/ball/ball_red.urdf', self.balls_location['red'], p.getQuaternionFromEuler([0,0,0]))
-            self.ball = p.loadURDF('urdf/ball/ball_blue.urdf', self.balls_location['blue'], p.getQuaternionFromEuler([0,0,0]))
-            self.ball = p.loadURDF('urdf/ball/ball_yellow.urdf', self.balls_location['yellow'], p.getQuaternionFromEuler([0,0,0]))
-            self.ball = p.loadURDF('urdf/ball/ball_green.urdf', self.balls_location['green'], p.getQuaternionFromEuler([0,0,0]))
+            self.ball_1 = p.loadURDF('urdf/ball/ball_red.urdf', self.balls_location['red'], p.getQuaternionFromEuler([0,0,0]))
+            self.ball_2 = p.loadURDF('urdf/ball/ball_blue.urdf', self.balls_location['blue'], p.getQuaternionFromEuler([0,0,0]))
+            self.ball_3 = p.loadURDF('urdf/ball/ball_yellow.urdf', self.balls_location['yellow'], p.getQuaternionFromEuler([0,0,0]))
+            self.ball_4 = p.loadURDF('urdf/ball/ball_green.urdf', self.balls_location['green'], p.getQuaternionFromEuler([0,0,0]))
         if self.humanoids_location is not None:
-            self.humnaoid = p.loadURDF('urdf/humanoid/humanoid_red.urdf', self.humanoids_location['red'], p.getQuaternionFromEuler([0,0,0]))  
-            self.humnaoid = p.loadURDF('urdf/humanoid/humanoid_blue.urdf', self.humanoids_location['blue'], p.getQuaternionFromEuler([0,0,0]))
-            self.humnaoid = p.loadURDF('urdf/humanoid/humanoid_yellow.urdf', self.humanoids_location['yellow'], p.getQuaternionFromEuler([0,0,0]))
-            self.humnaoid = p.loadURDF('urdf/humanoid/humanoid_green.urdf', self.humanoids_location['green'], p.getQuaternionFromEuler([0,0,0]))
+            self.humnaoid_1 = p.loadURDF('urdf/humanoid/humanoid_red.urdf', self.humanoids_location['red'], p.getQuaternionFromEuler([0,0,0]))  
+            self.humnaoid_2 = p.loadURDF('urdf/humanoid/humanoid_blue.urdf', self.humanoids_location['blue'], p.getQuaternionFromEuler([0,0,0]))
+            self.humnaoid_3 = p.loadURDF('urdf/humanoid/humanoid_yellow.urdf', self.humanoids_location['yellow'], p.getQuaternionFromEuler([0,0,0]))
+            self.humnaoid_4 = p.loadURDF('urdf/humanoid/humanoid_green.urdf', self.humanoids_location['green'], p.getQuaternionFromEuler([0,0,0]))
         if self.visual_cam_settings is not None:
             p.resetDebugVisualizerCamera(self.visual_cam_settings['cam_dist'], self.visual_cam_settings['cam_yaw'], self.visual_cam_settings['cam_pitch'], self.visual_cam_settings['cam_target_pos']) 
 
@@ -62,10 +61,10 @@ class VisionEnv(gym.Env):
         p.setJointMotorControl2(self.car,6,p.POSITION_CONTROL,targetPosition = 0)
         time.sleep(delay)
 
-    def get_image(self, dims=[512,512]):
+    def get_image(self, cam_height=0, dims=[512,512]):
         orn = p.getEulerFromQuaternion(p.getBasePositionAndOrientation(self.car)[1])
         pos = p.getBasePositionAndOrientation(self.car)[0]
-        pos = np.add(pos,np.array([0,0,self.cam_height]))
+        pos = np.add(pos,np.array([0,0,cam_height]))
         camera_eye = [pos[0]+0.4*np.cos(orn[2]),pos[1]+0.4*np.sin(orn[2]),pos[2]+1.15*np.cos(orn[0])]
         target_pos = [pos[0]-2*np.cos(orn[2]),pos[1]-2*np.sin(orn[2]),pos[2]+1.15*np.cos(orn[0])]
         view_matrix = p.computeViewMatrix(camera_eye, target_pos, [0,0,1])
